<#
* Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
* NOTICE: All information contained herein is, and remains the property of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and
* technical concepts contained herein are proprietary to ThreatSTOP, Inc. and its suppliers and certain aspects thereof are protected by United
* States Patent No. 8,533,822 and United States Patent No. 8,869,237, and are protected by trade secret or copyright law.
* US Government Entities: The ThreatSTOP service, software and documentation, as applicable, are "commercial computer software" and
* "commercial computer software documentation" developed exclusively at private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
* 12.212 or DFARS 227 7202 and their successors, as applicable, use, reproduction and disclosure of the software and documentation is
* governed by the terms of Threatstop's commercial agreement.
#>
# ErrID start: 50
# To uninstall ThreatSTOP DNS Policies for Windows 2016
# 1. load config values
# 2. delete ThreatSTOP scheduled tasks
# 3. remove secondary zones from DNS Server
# 4. remove ThreatSTOP DNS policies
# 5. turn off DNS Analytical log
############
$ErrorActionPreference = "Stop"

Write-Host "Starting ThreatSTOP DNS Policy Uninstall at $(Get-Date)"

#1 Load config values into hash table:
Write-Host "Loading configuration..."
$scriptPath = split-path -parent $MyInvocation.MyCommand.Definition
Get-Content "$scriptPath\ThreatSTOP.ini" | foreach-object -begin {$h=@{}} -process { $k = [regex]::split($_,'='); if(($k[0].CompareTo("") -ne 0) -and ($k[0].StartsWith("[") -ne $True -and $k[0].StartsWith("#")  -ne $True)) { $h.Add($k[0].Trim(), $k[1].Trim()) } }
$tszonename = $h.TSZoneName

#2 delete scheduled tasks
Write-Host "Removing scheduled tasks..."
$taskName = 'ThreatSTOP_policyrefresh'
$taskExists = Get-ScheduledTask | Where-Object {$_.TaskName -like $taskName }
if($taskExists) {
   Unregister-ScheduledTask -TaskName $taskName -Confirm:$false
}
$taskName = 'ThreatSTOP_exportDNSlog'
$taskExists = Get-ScheduledTask | Where-Object {$_.TaskName -like $taskName }
if($taskExists) {
   Unregister-ScheduledTask -TaskName $taskName -Confirm:$false
}
$taskName = 'ThreatSTOP_uploadDNSlog'
$taskExists = Get-ScheduledTask | Where-Object {$_.TaskName -like $taskName }
if($taskExists) {
   Unregister-ScheduledTask -TaskName $taskName -Confirm:$false
}

#3 Remove any DNS zones *.threatstop.local
Write-Host "Removing secondary zones from DNS..."
$zones = Get-DnsServerZone | Where {$_.ZoneType -eq "Secondary" -and $_.ZoneName -like "*.threatstop.local"}
ForEach ( $z in $zones)
{
    Remove-DnsServerZone -Name $z.ZoneName -Confirm:$false
}

#4 Remove ThreatSTOP DNS Policies:
$pol = Get-DnsServerQueryResolutionPolicy | Where {$_.Name -like "ThreatSTOPblock*"}
ForEach ($p in $pol)
{
    Write-Host "removing DNS policy $($p.Name)..."
    Remove-DnsServerQueryResolutionPolicy -Name $p.Name -Force
}

#5 Disable DNS Analytical Log
Write-Host "Disabling DNS Analytical Log..."
$DNSAnalyticalLog = Get-WinEvent -ListLog 'Microsoft-Windows-DNSServer/Analytical'
$DNSAnalyticalLog.IsEnabled = $false
$DNSAnalyticalLog.SaveChanges()

Write-Host -ForegroundColor Cyan "Run 'tsadmin add' to reinstall. You may also delete the folder and contents of $scriptPath"
Write-Host -ForegroundColor Green "Completed ThreatSTOP DNS Policy Uninstall at $(Get-Date)"